import pytest
from checkov.common.bridgecrew.severities import Severities
from checkov.policies_3d.runner import Policy3dRunner
from checkov.policies_3d.checks_parser import Policy3dParser
from checkov.common.bridgecrew.integration_features.features.policies_3d_integration import Policies3DIntegration


def test_runner_single_policy(policy_3d_1, scan_reports):
    # given
    checks = []
    parser = Policy3dParser()
    policies = [policy_3d_1]
    for policy in policies:
        converted_check = Policies3DIntegration._convert_raw_check(policy)
        check = parser.parse_raw_check(converted_check)
        check.severity = Severities[policy['severity']]
        check.bc_id = check.id
        checks.append(check)

    # when
    report = Policy3dRunner().run(checks=checks, scan_reports=scan_reports)

    # then
    assert len(report.failed_checks) == 1
    assert len(report.parsing_errors) == 0
    assert len(report.passed_checks) == 0
    assert len(report.skipped_checks) == 0


def test_runner_single_policy(policy_3d_1, scan_reports):
    # given
    checks = []
    parser = Policy3dParser()
    policies = [policy_3d_1]
    for policy in policies:
        converted_check = Policies3DIntegration._convert_raw_check(policy)
        check = parser.parse_raw_check(converted_check)
        check.severity = Severities[policy['severity']]
        check.bc_id = check.id
        checks.append(check)

    # when
    report = Policy3dRunner().run(checks=checks, scan_reports=scan_reports)

    # then
    assert len(report.failed_checks) == 1
    assert len(report.parsing_errors) == 0
    assert len(report.passed_checks) == 0
    assert len(report.skipped_checks) == 0


def test_runner_multi_policy(policy_3d_1, policy_3d_2, scan_reports):
    # given
    checks = []
    parser = Policy3dParser()
    policies = [policy_3d_1, policy_3d_2]
    for policy in policies:
        converted_check = Policies3DIntegration._convert_raw_check(policy)
        check = parser.parse_raw_check(converted_check)
        check.severity = Severities[policy['severity']]
        check.bc_id = check.id
        checks.append(check)

    # when
    report = Policy3dRunner().run(checks=checks, scan_reports=scan_reports)

    # then
    assert len(report.failed_checks) == 2
    assert len(report.parsing_errors) == 0
    assert len(report.passed_checks) == 0
    assert len(report.skipped_checks) == 0


def test_runner_multi_iac_checks_policy(policy_3d_3, scan_reports):
    # given
    checks = []
    parser = Policy3dParser()
    policies = [policy_3d_3]
    for policy in policies:
        converted_check = Policies3DIntegration._convert_raw_check(policy)
        check = parser.parse_raw_check(converted_check)
        check.severity = Severities[policy['severity']]
        check.bc_id = check.id
        checks.append(check)

    # when
    report = Policy3dRunner().run(checks=checks, scan_reports=scan_reports)

    # then
    assert len(report.failed_checks) == 1
    assert len(report.parsing_errors) == 0
    assert len(report.passed_checks) == 0
    assert len(report.skipped_checks) == 0

def test_runner_and_logic_for_iac_checks(policy_3d_3, scan_reports_2):
    # given
    checks = []
    parser = Policy3dParser()
    policies = [policy_3d_3]
    for policy in policies:
        converted_check = Policies3DIntegration._convert_raw_check(policy)
        check = parser.parse_raw_check(converted_check)
        check.severity = Severities[policy['severity']]
        check.bc_id = check.id
        checks.append(check)

    # when
    report = Policy3dRunner().run(checks=checks, scan_reports=scan_reports_2)

    # then
    # in this report there is only 1 matching IaC violation out of the 2 expected, so it should not create a violation
    assert len(report.failed_checks) == 0
    assert len(report.parsing_errors) == 0
    assert len(report.passed_checks) == 0
    assert len(report.skipped_checks) == 0


def test_run_v2(raw_3d_policy, scan_reports):
    # Arrange
    runner = Policy3dRunner()

    # Act
    report = runner.run_v2([raw_3d_policy], scan_reports)

    # Assert
    assert report
    assert len(report.failed_checks) == 1
    assert len(report.passed_checks) == 1
    assert len(report.failed_checks[0].composed_from_cves) == 2
    assert len(report.failed_checks[0].composed_from_iac_records) == 1




import os
import unittest

from checkov.cloudformation.checks.resource.aws.BedrockAgentEncrypted import check
from checkov.cloudformation.runner import Runner
from checkov.runner_filter import RunnerFilter


class TestBedrockAgentEncrypted(unittest.TestCase):

    def test_summary(self):
        runner = Runner()
        current_dir = os.path.dirname(os.path.realpath(__file__))
        test_files_dir = current_dir + "/example_BedrockAgentEncrypted"
        report = runner.run(root_folder=test_files_dir, runner_filter=RunnerFilter(checks=[check.id]))
        summary = report.get_summary()

        for record in report.failed_checks:
            self.assertEqual(record.check_id, check.id)

        for record in report.passed_checks:
            self.assertEqual(record.check_id, check.id)

        passing_resources = {
            "AWS::Bedrock::Agent.Pass",
        }

        failing_resources = {
            "AWS::Bedrock::Agent.Fail",

        }

        passed_check_resources = set([c.resource for c in report.passed_checks])
        failed_check_resources = set([c.resource for c in report.failed_checks])

        self.assertEqual(summary['passed'], 1)
        self.assertEqual(summary['failed'], 1)
        self.assertEqual(summary['skipped'], 0)
        self.assertEqual(summary['parsing_errors'], 0)
        self.assertEqual(passing_resources, passed_check_resources)
        self.assertEqual(failing_resources, failed_check_resources)


if __name__ == '__main__':
    unittest.main()



import unittest

import hcl2

from checkov.terraform.checks.resource.gcp.GoogleProjectAdminServiceAccount import check
from checkov.common.models.enums import CheckResult


class TestGoogleComputeDiskEncryption(unittest.TestCase):

    def test_failure(self):
        hcl_res = hcl2.loads("""
            resource "google_project_iam_member" "project" {
              project = "your-project-id"
              role    = "roles/owner"
              member  = "user:test@example-project.iam.gserviceaccount.com"
            }
                """)
        resource_conf = hcl_res['resource'][0]['google_project_iam_member']['project']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        hcl_res = hcl2.loads("""
            resource "google_project_iam_member" "project" {
              project = "your-project-id"
              role    = "roles/editor"
              member  = "user:jane@example.com"
            }
                """)
        resource_conf = hcl_res['resource'][0]['google_project_iam_member']['project']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

import hcl2

from checkov.common.models.enums import CheckResult
from checkov.terraform.checks.resource.gcp.CloudStorageLogging import check


class TestCloudStorageLogging(unittest.TestCase):

    def test_failure(self):
        hcl_res = hcl2.loads("""
        resource "google_storage_bucket" "logging" {
                name     = "jgwloggingbucket"
                location = var.location
                uniform_bucket_level_access = true
          }
        """)
        resource_conf = hcl_res['resource'][0]['google_storage_bucket']['logging']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        hcl_res = hcl2.loads("""
        resource "google_storage_bucket" "logging" {
                name     = "jgwloggingbucket"
                location = var.location
                uniform_bucket_level_access = true
                logging {
                  log_bucket = "mylovelybucket"
                }
          }
        """)
        resource_conf = hcl_res['resource'][0]['google_storage_bucket']['logging']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)

if __name__ == '__main__':
    unittest.main()
